# LSB Test Execution Framework
# Printing test module
#
# Copyright (C) 2007 The Linux Foundation. All rights reserved.
#
# This program has been developed by ISP RAS for LF with some parts
# derived from lsb-autotest written by Jiri Dluhos <jdluhos@suse.cz>
# Copyright (C) 2005-2007 SuSE Linux Products GmbH
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

package Printing_test;
use strict;

use Common;
use Packages;

use Tests::X11::X11_common;
@Printing_test::ISA = qw(X11_common);

=head ##
Class Printing_test Inherits X11_common;
=cut ##

sub new {
    my $self  = X11_common->new();
    $self->{NAME} = "printing";
    $self->{DISPLAYNAME} = "Printing Tests";
    $self->{DESCRIPTION} = "This package provides the LSB Runtime Printing Tests,"
                        ." for distribution certification.";
    $self->{PACKAGES} .= " lsb-tet3 lsb-test-printing";
    $self->{SOURCES} .= " runtime";
    $self->{BETA_SOURCES} .= " runtime";
    $self->{SNAPSHOT_SOURCES} .= " /snapshots/printing-test";

    bless($self);
    return $self;
}

sub check {
    my $self = shift;
    
    my $failed = 0;
    
    # TODO: Check cupsd is not running
    my $cupsd_pid = capture('ps -A | grep cupsd');
    chomp $cupsd_pid;
    debug_inform($cupsd_pid);
    if ( $cupsd_pid !~ /^\s*$/ ) {
        cmd('killall cupsd');
        
        # TODO: restore cupsd after testing.
        
        #$cupsd_pid =~ s/^\s*(\d+).*$/$1/;
        #complain ("cupsd is running on pid $cupsd_pid."
        #        ." Please stop this service and then re-run the tests.");
        #$failed = 1;
        ## TODO: Mind killall cupsd in cleanup()
    }
    
    return 0 if $failed;
    
    return Test_common::check($self);
}

# Run the test
sub run
{
    my $self = shift;
    
    return 1 if !$self->check();
    
    return Test_common::run($self);
}

sub journal {
    my $self = shift;
    
    store_journal_info(
        "Certification Tests/Runtime Interface Tests/".$self->{DISPLAYNAME},
        "printing_test", "$results_dir/test_journals/printing_test.journal", 
        $self);
}

sub cleanup {
    my $self = shift;
    
    cmd('killall cupsd');
    
    return X11_common::cleanup($self);
}

1; # return value
